# jemma

<img src="docs/jemma.gif" width="800">

```bash
$ python huddle.py --requirements /home/me/big-idea.txt --build-prototype --ollama
```

```bash
Ollama 🧠 gemma:7b-instruct-v1.1-fp16 ✅

> Project Manager: Dear Engineer, in this meeting let's put our heads together to build a prototype based on the requirements.

> Engineer: 💫 creating a prototype based on the requirements...
> Engineer: creating a css file 🎨 (a.k.a. "visual beauty")
> Engineer: creating a javascript file 🎮 (a.k.a. "master of interactions")
> Engineer: creating an html file 🕸️ (a.k.a. "the skeleton of the web")

prototype files created successfully:
- prototype/index.html
- prototype/app.js
- prototype/app.css
opened prototype in the web browser
```
